@@ -14,8 +14,9 @@ class Interval:
 	def get_le_signaling(self) -> int:
 		"""SCPI: CONFigure:BLUetooth:SIGNaling<Instance>:TCONnection:INTerval:LESignaling \n
 		Snippet: value: int = driver.configure.tconnection.interval.get_le_signaling() \n
-		No command help available \n
-			:return: connection_interval: No help available
+		Sets the time interval between the two consecutive connection events for LE test mode. The interval in ms is calculated
+		as the specified value multiplied by 1.25 ms. \n
+			:return: connection_interval: numeric Range: 6 to 3200
 		"""
 		response = self._core.io.query_str('CONFigure:BLUetooth:SIGNaling<Instance>:TCONnection:INTerval:LESignaling?')
 		return Conversions.str_to_int(response)
@@ -23,8 +24,9 @@ class Interval:
 	def set_le_signaling(self, connection_interval: int) -> None:
 		"""SCPI: CONFigure:BLUetooth:SIGNaling<Instance>:TCONnection:INTerval:LESignaling \n
 		Snippet: driver.configure.tconnection.interval.set_le_signaling(connection_interval = 1) \n
-		No command help available \n
-			:param connection_interval: No help available
+		Sets the time interval between the two consecutive connection events for LE test mode. The interval in ms is calculated
+		as the specified value multiplied by 1.25 ms. \n
+			:param connection_interval: numeric Range: 6 to 3200
 		"""
 		param = Conversions.decimal_value_to_str(connection_interval)
 		self._core.io.write(f'CONFigure:BLUetooth:SIGNaling<Instance>:TCONnection:INTerval:LESignaling {param}')
