@@ -18,6 +18,6 @@ class LeSignaling:
 		Snippet: value: enums.SignalingState = driver.connection.state.leSignaling.fetch() \n
 		Returns the signaling state of the R&S CMW for LE. State changes are initiated using the method RsCmwBluetoothSig.Call.
 		Connection.Action.leSignaling command. \n
-			:return: state: OFF | SBY | INQuiring | CNNecting | CONNected | DETaching | TCONected | TCNNecting OFF: not connected SBY: standby INQuiring: inquiring CNNecting: connecting CONNected: connected DETaching: detaching TCONected: LE test mode - connected TCNNecting: LE test mode - connecting"""
+			:return: state: OFF | SBY | INQuiring | CNNecting | CONNected | DETaching | TCONected | TCNNecting | CPOWer OFF: not connected SBY: standby INQuiring: inquiring CNNecting: connecting CONNected: connected DETaching: detaching TCONected: LE test mode - connected CPOWer: LE power control"""
 		response = self._core.io.query_str(f'FETCh:BLUetooth:SIGNaling<Instance>:CONNection:STATe:LESignaling?')
 		return Conversions.str_to_scalar_enum(response, enums.SignalingState)
